Made the dll entry point default to DllMain and removed most of the
'init' spec file declarations.

diff --git a/dlls/comctl32/commctrl.c b/dlls/comctl32/commctrl.c
index c29c40b..e39bcd6 100644
--- a/dlls/comctl32/commctrl.c
+++ b/dlls/comctl32/commctrl.c
@@ -127,7 +127,7 @@
 
 
 /***********************************************************************
  * COMCTL32_LibMain [Internal] Initializes the internal 'COMCTL32.DLL'.
  *
  * PARAMS
  *     hinstDLL    [I] handle to the 'dlls' instance
@@ -139,8 +139,7 @@
  *     Failure: FALSE
  */
 
-BOOL WINAPI
-COMCTL32_LibMain (HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved)
+BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved)
 {
     TRACE("%p,%lx,%p\n", hinstDLL, fdwReason, lpvReserved);
@@ -127,7 +127,7 @@
 
 /***********************************************************************
- * COMCTL32_LibMain [Internal] Initializes the internal 'COMCTL32.DLL'.
+ * DllMain [Internal] Initializes the internal 'COMCTL32.DLL'.
  *
  * PARAMS